#!/bin/bash

# Determine the directory where the script is located
SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"

# Define plugin files
VST3_DIR="/home/$USER/.vst3/"
VST2_DIR="/home/$USER/.vst/"
LV2_DIR="/home/$USER/.lv2"
CLAP_DIR="/home/$USER/.clap"
MANUAL_DIR="/opt/VZtec/Malibu"
PLUGIN_NAME="Malibu"
PLUGIN_SRC_DIR="$SCRIPT_DIR/files/Plugin"


# Function to install VST3 plugins
install_vst3() {
    # Check if PLUGIN_DIR exists
    SOURCE_DIR="$PLUGIN_SRC_DIR/VST3/$PLUGIN_NAME.vst3"
    
    if [ ! -d "$SOURCE_DIR" ]; then
        echo "Plugin directory not found: $SOURCE_DIR"
        exit 1
    fi

    # Check if the VST3 directory exists
    if [ ! -d "$VST3_DIR" ]; then
        echo "VST3 directory not found, creating..."
        sudo mkdir -p "$VST3_DIR"
    fi

    # Copy the PluginName.vst3 file to the VST3 directory
    sudo cp -r "$SOURCE_DIR" "$VST3_DIR"

    echo "VST3 plugin installed successfully to: $VST3_DIR"
}

# Function to install VST3 plugins
install_vst2() {
    # Check if PLUGIN_DIR exists
    SOURCE_DIR="$PLUGIN_SRC_DIR/VST/lib$PLUGIN_NAME.so"
    
    if [ ! -f "$SOURCE_DIR" ]; then
        echo "Plugin directory not found: $SOURCE_DIR"
        exit 1
    fi

    # Check if the VST3 directory exists
    if [ ! -d "$VST2_DIR" ]; then
        echo "VST2 directory not found, creating..."
        sudo mkdir -p "$VST2_DIR"
    fi

    # Copy the PluginName.vst3 file to the VST3 directory
    sudo cp -r "$SOURCE_DIR" "$VST2_DIR"

    echo "VST2 plugin installed successfully to: $VST2_DIR"
}


# Function to install LV2 plugins
install_lv2() {
    # Check if PLUGIN_DIR exists
    SOURCE_DIR="$PLUGIN_SRC_DIR/LV2/$PLUGIN_NAME.lv2"

    if [ ! -d "$SOURCE_DIR" ]; then
        echo "Plugin directory not found: $SOURCE_DIR"
        exit 1
    fi


    # Check if the VST3 directory exists
    if [ ! -d "$LV2_DIR" ]; then
        echo "LV2 directory not found, creating..."
        sudo mkdir -p "$LV2_DIR"
    fi

    # Copy the PluginName.vst3 file to the VST3 directory
    sudo cp -r "$SOURCE_DIR" "$LV2_DIR"

    echo "LV2 plugin installed successfully to: $LV2_DIR"
}


# Function to install CLAP plugins
install_clap() {

    # Check if the CLAP directory exists
    if [ ! -d "$CLAP_DIR" ]; then
        echo "CLAP directory not found, creating..."
        sudo mkdir -p "$CLAP_DIR"
    fi

    # Define the path to your CLAP plugin file
    SOURCE_DIR="$PLUGIN_SRC_DIR/CLAP/$PLUGIN_NAME.clap"

    # Check if the CLAP plugin file exists
    if [ ! -f "$SOURCE_DIR" ]; then
        echo "Plugin file not found: $SOURCE_DIR"
        exit 1
    fi

    # Copy the CLAP plugin file to the CLAP directory
    sudo cp "$SOURCE_DIR" "$CLAP_DIR"

    echo "CLAP plugin installed successfully to: $CLAP_DIR"
}

# Function to install User Manual
install_manual() {
    # Check if PLUGIN_DIR exists
    PLUGIN_DIR="$SCRIPT_DIR/files/Manuals"
    
    if [ ! -d "$PLUGIN_DIR" ]; then
        echo "Manual directory not found: $PLUGIN_DIR"
        exit 1
    fi


    # Check if the VST3 directory exists
    if [ ! -d "$MANUAL_DIR" ]; then
        echo "User Manual directory not found, creating..."
        sudo mkdir -p "$MANUAL_DIR"
    fi

    # Copy the PluginName.vst3 file to the VST3 directory
    sudo cp -r "$PLUGIN_DIR" "$MANUAL_DIR"

    echo "User manual installed successfully to: $MANUAL_DIR"
}

animated_dots() {
    for ((i = 0; i < 50; i++)); do
    echo -n "."
    sleep 0.01
done
echo ""
}

# Prompt the user for which formats to install
echo ""
echo "This script will install Malibu plugin in your system"
echo "Please select components to install"
echo ""

read -p "Do you want to install VST3 $PLUGIN_NAME plugin? (y/n): " install_vst3_response
read -p "Do you want to install VST2 $PLUGIN_NAME plugin? (y/n): " install_vst2_response
read -p "Do you want to install LV2 $PLUGIN_NAME plugin? (y/n): " install_lv2_response
read -p "Do you want to install CLAP $PLUGIN_NAME plugin? (y/n): " install_clap_response
read -p "Do you want to install User Manual? (y/n): " install_manual_response

echo ""
animated_dots
echo ""

# Install VST3 plugins if requested
if [[ $install_vst3_response =~ ^[Yy]*$ ]]; then
    install_vst3
    
fi

# Install VST2 plugins if requested
if [[ $install_vst2_response =~ ^[Yy]*$ ]]; then
    install_vst2
    
fi


# Install LV2 plugins if requested
if [[ $install_lv2_response =~ ^[Yy]*$ ]]; then
    install_lv2
    
fi

# Install CLAP plugins if requested
if [[ $install_clap_response =~ ^[Yy]*$ ]]; then
    install_clap
    
fi

# Install User Manual if requested
if [[ $install_manual_response =~ ^[Yy]*$ ]]; then
    install_manual
    
fi

echo ""
echo "$PLUGIN_NAME plugin succesfully installed."