#!/bin/bash

# Determine the directory where the script is located
SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"

# Define plugin files
PLUGIN_NAME="Malibu"
PLUGIN_VST3_DIR="/home/$USER/.vst3/$PLUGIN_NAME.vst3"
PLUGIN_VST2_DIR="/home/$USER/.vst/lib$PLUGIN_NAME.so"
PLUGIN_LV2_DIR="/home/$USER/.lv2/$PLUGIN_NAME.lv2"
PLUGIN_CLAP_FILE="/home/$USER/.clap/$PLUGIN_NAME.clap"
MANUAL_DIR="/opt/VZtec/Malibu/Manuals"


# Function to uninstall VST3 plugins
uninstall_vst3() {
    # Check if the VST3 plugin file exists
    if [ -d "$PLUGIN_VST3_DIR" ]; then
        sudo rm -rf "$PLUGIN_VST3_DIR"
        echo "VST3 plugin uninstalled successfully."
    else
        echo "VST3 plugin file not found."
    fi
}

# Function to uninstall VST2 plugins
uninstall_vst2() {
    # Check if the VST2 plugin file exists
    if [ -f "$PLUGIN_VST2_DIR" ]; then
        sudo rm -f "$PLUGIN_VST2_DIR"
        echo "VST2 plugin uninstalled successfully."
    else
        echo "VST2 plugin file not found."
    fi
}



# Function to uninstall LV2 plugins
uninstall_lv2() {
    # Check if the LV2 plugin file exists
    if [ -d "$PLUGIN_LV2_DIR" ]; then
        sudo rm -rf "$PLUGIN_LV2_DIR"
        echo "LV2 plugin uninstalled successfully."
    else
        echo "LV2 plugin file not found."
    fi
}

# Function to uninstall CLAP plugins
uninstall_clap() {
    # Check if the CLAP plugin file exists
    if [ -f "$PLUGIN_CLAP_FILE" ]; then
        sudo rm -f "$PLUGIN_CLAP_FILE"
        echo "CLAP plugin uninstalled successfully."
    else
        echo "CLAP plugin file not found."
    fi
}

# Function to uninstall user manual
uninstall_manual() {
    # Check if the user manual file exists
    if [ -d "$MANUAL_DIR" ]; then
        sudo rm -rf "$MANUAL_DIR"
        echo "User manual uninstalled successfully."
    else
        echo "User manual folder not found."
    fi
}


animated_dots() {
    for ((i = 0; i < 50; i++)); do
    echo -n "."
    sleep 0.01
done
echo""
}

echo ""
echo "This script will uninstall Malibu plugin from your system"
echo "Please select components to uninstall"
echo ""

# Prompt the user for which formats to uninstall
read -p "Do you want to uninstall VST3 $PLUGIN_NAME plugin? (y/n): " uninstall_vst3_response
read -p "Do you want to uninstall VST2 $PLUGIN_NAME plugin? (y/n): " uninstall_vst2_response
read -p "Do you want to uninstall LV2 $PLUGIN_NAME plugin? (y/n): " uninstall_lv2_response
read -p "Do you want to uninstall CLAP $PLUGIN_NAME plugin? (y/n): " uninstall_clap_response
read -p "Do you want to uninstall User Manual? (y/n): " uninstall_manual_response

echo ""
animated_dots
echo ""
# Uninstall VST3 plugins if requested
if [[ $uninstall_vst3_response =~ ^[Yy]*$ ]]; then
    uninstall_vst3
fi

# Uninstall VST2 plugins if requested
if [[ $uninstall_vst2_response =~ ^[Yy]*$ ]]; then
    uninstall_vst2
fi

# Uninstall LV2 plugins if requested
if [[ $uninstall_lv2_response =~ ^[Yy]*$ ]]; then
    uninstall_lv2
fi

# Uninstall CLAP plugins if requested
if [[ $uninstall_clap_response =~ ^[Yy]*$ ]]; then
    uninstall_clap
fi

# Uninstall MANUAL plugins if requested
if [[ $uninstall_manual_response =~ ^[Yy]*$ ]]; then
    uninstall_manual
fi

echo ""
echo "$PLUGIN_NAME plugin succesfully uninstalled."
